@@ -12,7 +12,7 @@ import pandas as pd
 from .cell import Column, Row, SubplotCell, TextCell, create_cell
 from .column_def import ColumnDefinition, ColumnType
 from .font import contrasting_font_color
-from .formatters import apply_string_formatter
+from .formatters import apply_formatter
 from .helpers import _replace_lw_key
 
 
@@ -53,9 +53,9 @@ class Table:
         column_border_kw (Dict[str, Any], optional):
             column_border_kw are passed to plt.plot. Defaults to {}.
         even_row_color (str | Tuple, optional):
-            facecolor of the even row cell's patches
+            facecolor of the even row cell's patches. Top Row has an even (0) index.
         odd_row_color (str | Tuple, optional):
-            facecolor of the even row cell's patches
+            facecolor of the even row cell's patches. Top Row has an even (0) index.
 
     Examples
     --------
@@ -139,12 +139,7 @@ class Table:
 
         self._plot_col_group_labels()
 
-        ymax = self.n_rows + 1
-        if len(self.col_group_cells) > 0:
-            ymax += 1
-
-        self.ax.set_xlim(0, sum(self._get_column_widths()) + 0.025)
-        self.ax.set_ylim(-0.025, ymax + 0.05)
+        ymax = self.n_rows
 
         if col_label_divider:
             self._plot_col_label_divider(**col_label_divider_kw)
@@ -154,6 +149,15 @@ class Table:
             self._plot_row_dividers(**row_divider_kw)
         self._plot_column_borders(**column_border_kw)
 
+        self.ax.set_xlim(-0.025, sum(self._get_column_widths()) + 0.025)
+        if self.col_group_cells:
+            miny = -2
+        else:
+            miny = -1
+
+        self.ax.set_ylim(miny - 0.025, ymax + 0.05)
+        self.ax.invert_yaxis()
+
         self._make_subplots()
 
     def _init_column_definitions(
@@ -226,7 +230,8 @@ class Table:
             x_min = min(col.get_xrange()[0] for col in columns)
             x_max = max(col.get_xrange()[1] for col in columns)
             dx = x_max - x_min
-            y = columns[0].get_yrange()[1] + 1
+
+            y = 0 - self.col_label_row.height
 
             textprops = self.textprops.copy()
             textprops.update({"ha": "center", "va": "bottom"})
@@ -243,7 +248,10 @@ class Table:
             )
             self.col_group_cells[group].draw()
             self.ax.plot(
-                [x_min + 0.05 * dx, x_max - 0.05 * dx], [y, y], lw=0.2, color="k"
+                [x_min + 0.05 * dx, x_max - 0.05 * dx],
+                [y, y],
+                lw=0.2,
+                color=plt.rcParams["text.color"],
             )
 
     def _plot_col_label_divider(self, **kwargs):
@@ -257,7 +265,7 @@ class Table:
         x0, x1 = self.rows[0].get_xrange()
         self.ax.plot(
             [x0, x1],
-            [self.n_rows, self.n_rows],
+            [0, 0],
             **COL_LABEL_DIVIDER_KW,
         )
 
@@ -270,7 +278,8 @@ class Table:
         self.FOOTER_DIVIDER_KW = FOOTER_DIVIDER_KW
 
         x0, x1 = list(self.rows.values())[-1].get_xrange()
-        self.ax.plot([x0, x1], [0, 0], **FOOTER_DIVIDER_KW)
+        y = len(self.df)
+        self.ax.plot([x0, x1], [y, y], **FOOTER_DIVIDER_KW)
 
     def _plot_row_dividers(self, **kwargs):
         """Plots lines between all TableRows."""
@@ -316,22 +325,38 @@ class Table:
     def _init_rows(self):
         """Initializes the Tables Rows."""
         self.rows = {}
-        for idx, values in enumerate(self.df.iloc[-1::-1].to_records()):
+        for idx, values in enumerate(self.df.to_records()):
             self.rows[idx] = self._get_row(idx, values)
 
-        self.col_label_row = self._get_col_label_row(idx + 1, self._get_column_titles())
+        self.col_label_row = self._get_col_label_row(-1, self._get_column_titles())
 
-    def get_column(self, name: str = None) -> Column:
+    def get_column(self, name: str) -> Column:
+        """Gets a Column by its column_name.
+
+        Args:
+            name (str): the column_name in the df.
+
+        Returns:
+            Column: A Column of the Table
+        """
         return self.columns[name]
 
     def get_column_by_index(self, index: int) -> Column:
+        """Gets a Column by its numeric index.
+
+        Args:
+            index (int): numeric index
+
+        Returns:
+            Column: A Column of the Table
+        """
         return list(self.columns.values())[index]
 
     def get_even_rows(self) -> List[Row]:
-        return list(self.rows.values())[-1::-2]
+        return list(self.rows.values())[::2]
 
     def get_odd_rows(self) -> List[Row]:
-        return list(self.rows.values())[-2::-2]
+        return list(self.rows.values())[1::2]
 
     def set_alternating_row_colors(
         self, color: str | Tuple[float] = None, color2: str | Tuple[float] = None
@@ -373,6 +398,11 @@ class Table:
         """
         widths = self._get_column_widths()
 
+        if "height" in self.col_label_cell_kw:
+            height = self.col_label_cell_kw["height"]
+        else:
+            height = 1
+
         x = 0
 
         row = Row(cells=[], index=idx)
@@ -389,11 +419,15 @@ class Table:
 
             cell = create_cell(
                 column_type=ColumnType.STRING,
-                xy=(x, idx),
+                xy=(
+                    x,
+                    idx + 1 - height,
+                ),  # if height is different from 1 we need to adjust y
                 content=_content,
                 row_idx=idx,
                 col_idx=col_idx,
                 width=width,
+                height=height,
                 rect_kw=self.col_label_cell_kw,
                 textprops=textprops,
                 ax=self.ax,
@@ -492,39 +526,38 @@ class Table:
                 if not hasattr(cell, "text"):
                     continue
 
-                if isinstance(formatter, str):
-                    formatted = apply_string_formatter(formatter, cell.content)
-                elif isinstance(formatter, Callable):
-                    formatted = formatter(cell.content)
-                else:
-                    msg = "You can provide builtin string formatters or a Callable to `formatter`."
-                    raise TypeError(msg)
-
+                formatted = apply_formatter(formatter, cell.content)
                 cell.text.set_text(formatted)
 
     def _apply_column_cmaps(self) -> None:
         for colname, _dict in self.column_definitions.items():
             cmap_fn = _dict.get("cmap")
-            if cmap_fn is not None:
-                for cell in self.columns[colname].cells:
-                    if isinstance(cell.content, Number):
-                        if ("bbox" in _dict.get("textprops")) & hasattr(cell, "text"):
-                            cell.text.set_bbox(
-                                {
-                                    "color": cmap_fn(cell.content),
-                                    **_dict.get("textprops").get("bbox"),
-                                }
-                            )
-                        else:
-                            cell.rectangle_patch.set_facecolor(cmap_fn(cell.content))
+            if cmap_fn is None:
+                continue
+
+            for cell in self.columns[colname].cells:
+                if not isinstance(cell.content, Number):
+                    continue
+
+                if ("bbox" in _dict.get("textprops")) & hasattr(cell, "text"):
+                    cell.text.set_bbox(
+                        {
+                            "color": cmap_fn(cell.content),
+                            **_dict.get("textprops").get("bbox"),
+                        }
+                    )
+                else:
+                    cell.rectangle_patch.set_facecolor(cmap_fn(cell.content))
 
     def _apply_column_text_cmaps(self) -> None:
         for colname, _dict in self.column_definitions.items():
             cmap_fn = _dict.get("text_cmap")
-            if cmap_fn is not None:
-                for cell in self.columns[colname].cells:
-                    if isinstance(cell.content, Number) & hasattr(cell, "text"):
-                        cell.text.set_color(cmap_fn(cell.content))
+            if cmap_fn is None:
+                continue
+
+            for cell in self.columns[colname].cells:
+                if isinstance(cell.content, Number) & hasattr(cell, "text"):
+                    cell.text.set_color(cmap_fn(cell.content))
 
     def autoset_fontcolors(
         self, fn: Callable = None, colnames: List[str] = None, **kwargs
